#!/bin/bash

set -euo pipefail

SCRIPT_DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" &> /dev/null && pwd )"

# Create buildx builder if it doesn't exist
docker buildx create --name multiarch --use 2>/dev/null || docker buildx use multiarch

# Detect if we're building for testing or publishing
if [ "${BUILD_MODE:-test}" = "multiarch" ]; then
  # Build multi-platform image (for publishing)
  docker buildx build \
    --platform linux/amd64,linux/arm64 \
    -t "gitea.jde.nz/public/dropshell-build-base:latest" \
    -f "${SCRIPT_DIR}/Dockerfile.dropshell-build-base" \
    ${SCRIPT_DIR}
else
  # Build single-platform image for current architecture and load it
  docker buildx build \
    --load \
    -t "gitea.jde.nz/public/dropshell-build-base:latest" \
    -f "${SCRIPT_DIR}/Dockerfile.dropshell-build-base" \
    ${SCRIPT_DIR}
fi
  