#!/bin/bash

set -euo pipefail

SCRIPT_DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" &> /dev/null && pwd )"


export CMAKE_BUILD_TYPE="Debug"

rm -rf "${SCRIPT_DIR}/output" 
mkdir -p "${SCRIPT_DIR}/output"

# If PROJECT is set, build only that project
if [ -n "${PROJECT:-}" ]; then
  docker build \
    -t "gitea.jde.nz/public/${PROJECT}-build:latest" \
    -f "${SCRIPT_DIR}/Dockerfile.dropshell-build" \
    --build-arg PROJECT="${PROJECT}" \
    --build-arg CMAKE_BUILD_TYPE="${CMAKE_BUILD_TYPE}" \
    --output "${SCRIPT_DIR}/output" \
    "${SCRIPT_DIR}/tests/${PROJECT}"
else
  # Build all projects
  PROJECT="ipdemo"
  docker build \
    -t "gitea.jde.nz/public/${PROJECT}-build:latest" \
    -f "${SCRIPT_DIR}/Dockerfile.dropshell-build" \
    --build-arg PROJECT="${PROJECT}" \
    --build-arg CMAKE_BUILD_TYPE="${CMAKE_BUILD_TYPE}" \
    --output "${SCRIPT_DIR}/output" \
    "${SCRIPT_DIR}/tests/${PROJECT}"



  # Test aarch64 build of ipdemo
  echo "Building ipdemo for aarch64..."
  PROJECT="ipdemo"
  docker buildx build \
      --platform linux/arm64 \
      -t "gitea.jde.nz/public/ipdemo-build:aarch64" \
      -f "${SCRIPT_DIR}/Dockerfile.dropshell-build" \
      --build-arg PROJECT="${PROJECT}" \
      --build-arg CMAKE_BUILD_TYPE="Debug" \
      --output "${SCRIPT_DIR}/output/aarch64" \
      "${SCRIPT_DIR}/tests/${PROJECT}"


  PROJECT="test_libs"
  docker build \
    -t "gitea.jde.nz/public/${PROJECT}-build:latest" \
    -f "${SCRIPT_DIR}/Dockerfile.dropshell-build" \
    --build-arg PROJECT="${PROJECT}" \
    --build-arg CMAKE_BUILD_TYPE="${CMAKE_BUILD_TYPE}" \
    --output "${SCRIPT_DIR}/output" \
    "${SCRIPT_DIR}/tests/${PROJECT}"
fi

